==> kpopup-0.7.0.tar.gz: kpopup-0.7.0/kpopup/main.cpp <==

/***************************************************************************
                          main.cpp  -  description
                             -------------------
    copyright            : (C) 2000 by Torsten Henschel
    email                : henschel@fh-brandenburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>

#include "kpopup.h"

static const char *description = "KPopup";
// INSERT A DESCRIPTION FOR YOUR APPLICATION HERE
	
	
static KCmdLineOptions options[] =
{
  { 0, 0, 0 }
  // INSERT YOUR COMMANDLINE OPTIONS HERE
};

int main(int argc, char *argv[])
{

  KAboutData aboutData("kpopup", "KPopup", VERSION, description, KAboutData::License_GPL,
                       "(c) 2000, Torsten Henschel");
  aboutData.addAuthor("Torsten Henschel", 0, "henschel@fh-brandenburg.de");
  KCmdLineArgs::init(argc, argv, &aboutData);
  KCmdLineArgs::addCmdLineOptions(options); // Add our own options.

  KApplication a(argc, argv, "kpopup");

  if(argc != 1)
   {
    a.beep();
   }

  Kpopup *w = new Kpopup(argc, argv);
  w -> setGeometry(100, 100, 400, 400);
  w -> setCaption("KPopup");
  a.setMainWidget(w);
  w -> show();

  return a.exec();
}

==> kpopup-0.7.1.tar.gz: kpopup-0.7.1/kpopup/main.cpp <==

/***************************************************************************
                          main.cpp  -  description
                             -------------------
    copyright            : (C) 2000 by Torsten Henschel
    email                : henschel@fh-brandenburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>

#include "kpopup.h"

static const char *description = "KPopup";
// INSERT A DESCRIPTION FOR YOUR APPLICATION HERE
	
	
/*static KCmdLineOptions options[] =
{
  { 0, 0, 0 }
  // INSERT YOUR COMMANDLINE OPTIONS HERE
};*/

int main(int argc, char *argv[])
{

  KAboutData aboutData("kpopup", "KPopup", VERSION, description, KAboutData::License_GPL,
                       "(c) 2000, Torsten Henschel");
  aboutData.addAuthor("Torsten Henschel", 0, "henschel@fh-brandenburg.de");
//  KCmdLineArgs::init(argc, argv, &aboutData);
//  KCmdLineArgs::addCmdLineOptions(options); // Add our own options.

  KApplication a(argc, argv, "kpopup");

  if(argc != 1)
   {
    a.beep();
   }

  Kpopup *w = new Kpopup(argc, argv);
  w -> setGeometry(100, 100, 400, 400);
  w -> setCaption("KPopup");
  a.setMainWidget(w);
  w -> show();

  return a.exec();
}
